searchData={"items":[{"type":"module","title":"Mint.WebSocket","doc":"HTTP/1 and HTTP/2 WebSocket support for the Mint functional HTTP client\n\nLike Mint, `Mint.WebSocket` provides a functional, process-less interface\nfor operating a WebSocket connection. Prospective Mint.WebSocket users\nmay wish to first familiarize themselves with `Mint.HTTP`.\n\nMint.WebSocket is not fully spec-conformant on its own. Runtime behaviors\nsuch as responding to pings with pongs must be implemented by the user of\nMint.WebSocket.","ref":"Mint.WebSocket.html"},{"type":"module","title":"Usage - Mint.WebSocket","doc":"A connection formed with `Mint.HTTP.connect/4` can be upgraded to a WebSocket\nconnection with `upgrade/5`.\n\n```elixir\n{:ok, conn} = Mint.HTTP.connect(:http, \"localhost\", 9_000)\n{:ok, conn, ref} = Mint.WebSocket.upgrade(:ws, conn, \"/\", [])\n```\n\n`upgrade/5` sends an upgrade request to the remote server. The WebSocket\nconnection is then built by awaiting the HTTP response from the server.\n\n```elixir\nhttp_reply_message = receive(do: (message -> message))\n{:ok, conn, [{:status, ^ref, status}, {:headers, ^ref, resp_headers}, {:done, ^ref}]} =\n  Mint.WebSocket.stream(conn, http_reply_message)\n\n{:ok, conn, websocket} =\n  Mint.WebSocket.new(conn, ref, status, resp_headers)\n```\n\nOnce the WebSocket connection has been established, use the `websocket`\ndata structure to encode and decode frames with `encode/2` and `decode/2`,\nand send and stream messages with `stream_request_body/3` and `stream/2`.\n\nFor example, one may send a \"hello world\" text frame across a connection\nlike so:\n\n```elixir\n{:ok, websocket, data} = Mint.WebSocket.encode(websocket, {:text, \"hello world\"})\n{:ok, conn} = Mint.WebSocket.stream_request_body(conn, ref, data)\n```\n\nSay that the remote is echoing messages. Use `stream/2` and `decode/2` to\ndecode a received WebSocket frame:\n\n```elixir\necho_message = receive(do: (message -> message))\n{:ok, conn, [{:data, ^ref, data}]} = Mint.WebSocket.stream(conn, echo_message)\n{:ok, websocket, [{:text, \"hello world\"}]} = Mint.WebSocket.decode(websocket, data)\n```","ref":"Mint.WebSocket.html#module-usage"},{"type":"module","title":"HTTP/2 Support - Mint.WebSocket","doc":"Mint.WebSocket supports WebSockets over HTTP/2 as defined in rfc8441.\nrfc8441 is an extension to the HTTP/2 specification. At the time of\nwriting, very few HTTP/2 server libraries support or enable HTTP/2\nWebSockets by default.\n\n`upgrade/5` works on both HTTP/1 and HTTP/2 connections. In order to select\nHTTP/2, the `:http2` protocol should be explicitly selected in\n`Mint.HTTP.connect/4`.\n\n```elixir\n{:ok, conn} =\n  Mint.HTTP.connect(:http, \"websocket.example\", 80, protocols: [:http2])\n:http2 = Mint.HTTP.protocol(conn)\n{:ok, conn, ref} = Mint.WebSocket.upgrade(:ws, conn, \"/\", [])\n```\n\nIf the server does not support the extended CONNECT method needed to bootstrap\nWebSocket connections over HTTP/2, `upgrade/4` will return an error tuple\nwith the `:extended_connect_disabled` error reason.\n\n```elixir\n{:error, conn, %Mint.WebSocketError{reason: :extended_connect_disabled}}\n```\n\nWhy use HTTP/2 for WebSocket connections in the first place? HTTP/2\ncan multiplex many requests over the same connection, which can\nreduce the latency incurred by forming new connections for each request.\nA WebSocket connection only occupies one stream of a HTTP/2 connection, so\neven if an HTTP/2 connection has an open WebSocket communication, it can be\nused to transport more requests.","ref":"Mint.WebSocket.html#module-http-2-support"},{"type":"module","title":"WebSocket Secure - Mint.WebSocket","doc":"Encryption of connections is handled by Mint functions. To start a WSS\nconnection, select `:https` as the scheme in `Mint.HTTP.connect/4`:\n\n```elixir\n{:ok, conn} = Mint.HTTP.connect(:https, \"websocket.example\", 443)\n```\n\nAnd pass the `:wss` scheme to `upgrade/5`. See the Mint documentation\non SSL for more information.","ref":"Mint.WebSocket.html#module-websocket-secure"},{"type":"module","title":"Extensions - Mint.WebSocket","doc":"The WebSocket protocol allows for _extensions_. Extensions act as a\nmiddleware for encoding and decoding frames. For example \"permessage-deflate\"\ncompresses and decompresses the body of data frames, which minifies the amount\nof bytes which must be sent over the network.\n\nSee `Mint.WebSocket.Extension` for more information about extensions and\n`Mint.WebSocket.PerMessageDeflate` for information about the\n\"permessage-deflate\" extension.","ref":"Mint.WebSocket.html#module-extensions"},{"type":"function","title":"Mint.WebSocket.decode/2","doc":"Decodes a binary into a list of frames\n\nThe binary may received from the connection with `Mint.HTTP.stream/2`.\n\nThis function will invoke the `c:Mint.WebSocket.Extension.decode/2` callback\nfor any accepted extensions.","ref":"Mint.WebSocket.html#decode/2"},{"type":"function","title":"Examples - Mint.WebSocket.decode/2","doc":"```elixir\nmessage = receive(do: (message -> message))\n{:ok, conn, [{:data, ^ref, data}]} = Mint.HTTP.stream(conn, message)\n{:ok, websocket, frames} = Mint.WebSocket.decode(websocket, data)\n```","ref":"Mint.WebSocket.html#decode/2-examples"},{"type":"function","title":"Mint.WebSocket.encode/2","doc":"Encodes a frame into a binary\n\nThe resulting binary may be sent with `stream_request_body/3`.\n\nThis function will invoke the `c:Mint.WebSocket.Extension.encode/2` callback\nfor any accepted extensions.","ref":"Mint.WebSocket.html#encode/2"},{"type":"function","title":"Examples - Mint.WebSocket.encode/2","doc":"```elixir\n{:ok, websocket, data} = Mint.WebSocket.encode(websocket, {:text, \"hello world\"})\n{:ok, conn} = Mint.WebSocket.stream_request_body(conn, websocket_ref, data)\n```","ref":"Mint.WebSocket.html#encode/2-examples"},{"type":"function","title":"Mint.WebSocket.new/5","doc":"Creates a new WebSocket data structure given the server's reply to the\nupgrade request\n\nThis function will setup any extensions accepted by the server using\nthe `c:Mint.WebSocket.Extension.init/2` callback.","ref":"Mint.WebSocket.html#new/5"},{"type":"function","title":"Options - Mint.WebSocket.new/5","doc":"* `:mode` - (default: `:active`) either `:active` or `:passive`. This\n  corresponds to the same option in `Mint.HTTP.connect/4`.","ref":"Mint.WebSocket.html#new/5-options"},{"type":"function","title":"Examples - Mint.WebSocket.new/5","doc":"```elixir\nhttp_reply = receive(do: (message -> message))\n{:ok, conn, [{:status, ^ref, status}, {:headers, ^ref, headers}, {:done, ^ref}]} =\n  Mint.WebSocket.stream(conn, http_reply)\n\n{:ok, conn, websocket} =\n  Mint.WebSocket.new(conn, ref, status, resp_headers)\n```","ref":"Mint.WebSocket.html#new/5-examples"},{"type":"function","title":"Mint.WebSocket.recv/3","doc":"Receives data from the socket\n\nThis function is used instead of `stream/2` when the connection is\nin `:passive` mode. You must pass the `mode: :passive` option to\n`new/5` in order to use `recv/3`.\n\nThis function wraps `Mint.HTTP.recv/3`. See the `Mint.HTTP.recv/3`\ndocumentation for more information.","ref":"Mint.WebSocket.html#recv/3"},{"type":"function","title":"Examples - Mint.WebSocket.recv/3","doc":"{:ok, conn, [{:data, ^ref, data}]} = Mint.WebSocket.recv(conn, 0, 5_000)\n    {:ok, websocket, [{:text, \"hello world!\"}]} =\n      Mint.WebSocket.decode(websocket, data)","ref":"Mint.WebSocket.html#recv/3-examples"},{"type":"function","title":"Mint.WebSocket.stream/2","doc":"A wrapper around `Mint.HTTP.stream/2` for streaming HTTP and WebSocket\nmessages\n\nThis function does not decode WebSocket frames. Instead, once a WebSocket\nconnection has been established, decode any `{:data, request_ref, data}`\nframes with `decode/2`.\n\nThis function is a drop-in replacement for `Mint.HTTP.stream/2` which\nenables streaming WebSocket data after the bootstrapping HTTP/1 connection\nhas concluded. It decodes both WebSocket and regular HTTP messages.","ref":"Mint.WebSocket.html#stream/2"},{"type":"function","title":"Examples - Mint.WebSocket.stream/2","doc":"message = receive(do: (message -> message))\n    {:ok, conn, [{:data, ^websocket_ref, data}]} =\n      Mint.WebSocket.stream(conn, message)\n    {:ok, websocket, [{:text, \"hello world!\"}]} =\n      Mint.WebSocket.decode(websocket, data)","ref":"Mint.WebSocket.html#stream/2-examples"},{"type":"function","title":"Mint.WebSocket.stream_request_body/3","doc":"Streams chunks of data on the connection\n\n`stream_request_body/3` should be used to send encoded data on an\nestablished WebSocket connection that has already been upgraded with\n`upgrade/5`.\n\nThis function is a wrapper around `Mint.HTTP.stream_request_body/3`. It\ndelegates to that function unless the `request_ref` belongs to an HTTP/1\nWebSocket connection. When the request is an HTTP/1 WebSocket, this\nfunction allows sending data on a request which Mint considers to be\nclosed, but is actually a valid WebSocket connection.\n\nSee the `Mint.HTTP.stream_request_body/3` documentation for more\ninformation.","ref":"Mint.WebSocket.html#stream_request_body/3"},{"type":"function","title":"Examples - Mint.WebSocket.stream_request_body/3","doc":"{:ok, websocket, data} = Mint.WebSocket.encode(websocket, {:text, \"hello world!\"})\n    {:ok, conn} = Mint.WebSocket.stream_request_body(conn, websocket_ref, data)","ref":"Mint.WebSocket.html#stream_request_body/3-examples"},{"type":"function","title":"Mint.WebSocket.upgrade/5","doc":"Requests that a connection be upgraded to the WebSocket protocol\n\nThis function wraps `Mint.HTTP.request/5` to provide a single interface\nfor bootstrapping an upgrade for HTTP/1 and HTTP/2 connections.\n\nFor HTTP/1 connections, this function performs a GET request with\nWebSocket-specific headers. For HTTP/2 connections, this function performs\nan extended CONNECT request which opens a stream to be used for the WebSocket\nconnection.\n\nThe `scheme` argument should be either `:ws` or `:wss`, using `:ws` for\nconnections established by passing `:http` to `Mint.HTTP.connect/4` and\n`:wss` corresponding to `:https`.","ref":"Mint.WebSocket.html#upgrade/5"},{"type":"function","title":"Options - Mint.WebSocket.upgrade/5","doc":"* `:extensions` - a list of extensions to negotiate. See the extensions\n  section below.","ref":"Mint.WebSocket.html#upgrade/5-options"},{"type":"function","title":"Extensions - Mint.WebSocket.upgrade/5","doc":"Extensions should be declared by passing the `:extensions` option in the\n`opts` keyword list. Note that in the WebSocket protocol, extensions are\nnegotiated: the client proposes a list of extensions and the server may\naccept any (or none) of them. See `Mint.WebSocket.Extension` for more\ninformation about extension negotiation.\n\nExtensions may be passed as a list of `Mint.WebSocket.Extension` structs\nor with the following shorthand notations:\n\n* `module` - shorthand for `{module, []}`\n* `{module, params}` - shorthand for `{module, params, []}`\n* `{module, params, opts}` - a shorthand which is expanded to a\n  `Mint.WebSocket.Extension` struct","ref":"Mint.WebSocket.html#upgrade/5-extensions"},{"type":"function","title":"Examples - Mint.WebSocket.upgrade/5","doc":"```elixir\n{:ok, conn} = Mint.HTTP.connect(:http, \"localhost\", 9_000)\n{:ok, conn, ref} =\n  Mint.WebSocket.upgrade(:ws, conn, \"/\", [], extensions: [Mint.WebSocket.PerMessageDeflate])\n# or provide params:\n{:ok, conn, ref} =\n  Mint.WebSocket.upgrade(\n    :ws,\n    conn,\n    \"/\",\n    [],\n    extensions: [{Mint.WebSocket.PerMessageDeflate, [:client_max_window_bits]]}]\n  )\n```","ref":"Mint.WebSocket.html#upgrade/5-examples"},{"type":"type","title":"Mint.WebSocket.error/0","doc":"","ref":"Mint.WebSocket.html#t:error/0"},{"type":"type","title":"Mint.WebSocket.frame/0","doc":"A WebSocket frame\n\n* `{:binary, binary}` - a frame containing binary data. Binary frames\n  can be used to send arbitrary binary data such as a PDF.\n* `{:text, text}` - a frame containing string data. Text frames must be\n  valid utf8. Elixir has wonderful support for utf8: `String.valid?/1`\n  can detect valid and invalid utf8.\n* `{:ping, binary}` - a control frame which the server should respond to\n  with a pong. The binary data must be echoed in the pong response.\n* `{:pong, binary}` - a control frame which forms a reply to a ping frame.\n  Pings and pongs may be used to check the a connection is alive or to\n  estimate latency.\n* `{:close, code, reason}` - a control frame used to request that a connection\n  be closed or to acknowledgee a close frame send by the server.\n\nThese may be passed to `encode/2` or returned from `decode/2`.","ref":"Mint.WebSocket.html#t:frame/0"},{"type":"type","title":"Close frames - Mint.WebSocket.frame/0","doc":"In order to close a WebSocket connection gracefully, either the client or\nserver sends a close frame. Then the other endpoint responds with a\nclose with code `1_000` and then closes the TCP connection. This can be\naccomplished in Mint.WebSocket like so:\n\n```elixir\n{:ok, websocket, data} = Mint.WebSocket.encode(websocket, :close)\n{:ok, conn} = Mint.WebSocket.stream_request_body(conn, ref, data)\n\nclose_response = receive(do: (message -> message))\n{:ok, conn, [{:data, ^ref, data}]} = Mint.WebSocket.stream(conn, close_response)\n{:ok, websocket, [{:close, 1_000, \"\"}]} = Mint.WebSocket.decode(websocket, data)\n\nMint.HTTP.close(conn)\n```\n\n[rfc6455\nsection 7.4.1](https://datatracker.ietf.org/doc/html/rfc6455#section-7.4.1)\ndocuments codes which may be used in the `code` element.","ref":"Mint.WebSocket.html#t:frame/0-close-frames"},{"type":"type","title":"Mint.WebSocket.shorthand_frame/0","doc":"Shorthand notations for control frames\n\n* `:ping` - shorthand for `{:ping, \"\"}`\n* `:pong` - shorthand for `{:pong, \"\"}`\n* `:close` - shorthand for `{:close, nil, nil}`\n\nThese may be passed to `encode/2`. Frames decoded with `decode/2` are always\nin `t:frame/0` format.","ref":"Mint.WebSocket.html#t:shorthand_frame/0"},{"type":"opaque","title":"Mint.WebSocket.t/0","doc":"An immutable data structure representing a WebSocket connection","ref":"Mint.WebSocket.html#t:t/0"},{"type":"behaviour","title":"Mint.WebSocket.Extension","doc":"Tools for defining extensions to the WebSocket protocol\n\nThe WebSocket protocol allows for extensions which act as middle-ware\nin the encoding and decoding of frames. In `Mint.WebSocket`, extensions are\nwritten as module which implement the `Mint.WebSocket.Extension` behaviour.\n\nThe common \"permessage-deflate\" extension is built-in to `Mint.WebSocket` as\n`Mint.WebSocket.PerMessageDeflate`. This extension should be used as a\nreference when writing future extensions, but future extensions should be\nwritten as separate libraries which extend `Mint.WebSocket` instead of\nbuilt-in. Also note that extensions must operate on the internal\nrepresentations of frames using the records defined in `Mint.WebSocket.Frame`,\nwhich are not documented.","ref":"Mint.WebSocket.Extension.html"},{"type":"callback","title":"Mint.WebSocket.Extension.decode/2","doc":"Invoked when decoding frames after receiving them from the wire\n\nError tuples bubble up to `Mint.WebSocket.decode/2`.","ref":"Mint.WebSocket.Extension.html#c:decode/2"},{"type":"callback","title":"Mint.WebSocket.Extension.encode/2","doc":"Invoked when encoding frames before sending them across the wire\n\nError tuples bubble up to `Mint.WebSocket.encode/2`.","ref":"Mint.WebSocket.Extension.html#c:encode/2"},{"type":"callback","title":"Mint.WebSocket.Extension.init/2","doc":"Invoked when the WebSocket server accepts an extension\n\nThis callback should be used to initialize any `:state` that the extension\nneeds to operate. For example, this callback is used by the\n\"permessage-deflate\" extension to setup `t::zlib.zstream()`s and store\nthem in state.\n\nThe `all_extensions` argument is passed so that the extension can know\nabout the existence and ordering of other extensions. This can be useful\nif a client declares multiple extensions which accomplish the same job\n(such as multiple compression extensions) but want to only enable one based\non what the server accepts.\n\nNote that extensions are initialized in the order in which the server accepts\nthem: any extensions preceeding `this_extension` in `all_extensions` are\ninitialized while any extensions after `this_extension` are not yet\ninitialized.\n\nError tuples bubble up to `Mint.WebSocket.upgrade/4`.","ref":"Mint.WebSocket.Extension.html#c:init/2"},{"type":"callback","title":"Mint.WebSocket.Extension.name/0","doc":"Returns the name of the WebSocket extension\n\nThis should not include the parameters for the extension, such as\n\"client_max_window_bits\" for the \"permessage-deflate\" extension.","ref":"Mint.WebSocket.Extension.html#c:name/0"},{"type":"callback","title":"Examples - Mint.WebSocket.Extension.name/0","doc":"iex> Mint.WebSocket.PerMessageDeflate.name()\n    \"permessage-deflate\"","ref":"Mint.WebSocket.Extension.html#c:name/0-examples"},{"type":"type","title":"Mint.WebSocket.Extension.params/0","doc":"Parameters to configure an extension\n\nSome extensions can be configured by negotiation between the client and\nserver. For example \"permessage-deflate\" usually shows up as in the\n\"sec-websocket-extensions\" header literally like so:\n\n```text\nSec-WebSocket-Extensions: permessage-deflate\n```\n\nBut the zlib window sizes and reset behavior can be negotiated with parameters\nwith headers like so\n\n```text\nSec-WebSocket-Extensions: permessage-deflate; client_no_context_takeover; client_max_window_bits=12\n```\n\nThese can be configured by passing parameters to any element passed in the\n`:extensions` option to `Mint.WebSocket.upgrade/4`.\n\nFor example, one might write the above parameter configuration as\n\n```elixir\n[\n  {Mint.WebSocket.PerMessageDeflate,\n   [client_no_context_takeover: true, client_max_window_bits: 12]}\n]\n```\n\nwhen passing the `:extensions` option to `Mint.WebSocket.upgrade/4`.\n\nNote that `Mint.WebSocket.upgrade/4` will normalize the parameters of an\nextension to a list of two-tuples with string keys and values. For example,\nthe above would be normalized to this extensions list:\n\n```elixir\n[\n  %Mint.WebSocket.Extension{\n    name: \"permessage-deflate\",\n    module: Mint.WebSocket.PerMessageDeflate,\n    params: [\n      {\"client_no_context_takeover\", \"true\"},\n      {\"client_max_window_bits\", \"12\"}\n    ],\n    state: nil,\n    opts: []\n  }\n]\n```","ref":"Mint.WebSocket.Extension.html#t:params/0"},{"type":"type","title":"Mint.WebSocket.Extension.t/0","doc":"A structure representing an instance of an extension\n\nExtensions are implemented as modules but passed to `Mint.WebSocket` as\n`Mint.WebSocket.Extension` structs with the following keys:\n\n* `:name` - the name of the extension. When using the short-hand tuple\n  syntax to pass extensions to `Mint.WebSocket.upgrade/4`, the name is\n  determined by calling the `c:name/0` callback.\n* `:module` - the module which implements the callbacks defined in the\n  `Mint.WebSocket.Extension` behavior.\n* `:state` - an arbitrary piece of data curated by the extension. For\n  example, the \"permessage-deflate\" extension uses this field to\n  hold `t:zlib.zstream()`s for compression and decompression.\n* `:params` - a list with key-value tuples or atom/string keys which configure\n  the parameters communicated to the server. All params are encoded into the\n  \"sec-websocket-extensions\" header. Also see the documentation for\n  `t:params/0`.\n* `:opts` - a keyword list to pass configuration to the extension. These\n  are not encoded into the \"sec-websocket-extensions\" header. For example,\n  `:opts` is used by the \"permessage-deflate\" extension to configure `:zlib`\n  configuration.","ref":"Mint.WebSocket.Extension.html#t:t/0"},{"type":"module","title":"Mint.WebSocket.PerMessageDeflate","doc":"A WebSocket extension which compresses each message before sending it across\nthe wire\n\nThis extension is defined in\n[rfc7692](https://www.rfc-editor.org/rfc/rfc7692.html).","ref":"Mint.WebSocket.PerMessageDeflate.html"},{"type":"module","title":"Options - Mint.WebSocket.PerMessageDeflate","doc":"* `:zlib_level` - (default: `:best_compression`) the compression level to\n  use for the deflation zstream. See the `:zlib.deflateInit/6` documentation\n  on the `Level` argument.\n* `:zlib_memory_level` - (default: `8`) how much memory to allow for use\n  during compression. See the `:zlib.deflateInit/6` documentation on the\n  `MemLevel` argument.","ref":"Mint.WebSocket.PerMessageDeflate.html#module-options"},{"type":"exception","title":"Mint.WebSocket.UpgradeFailureError","doc":"An error representing a failure to upgrade protocols from HTTP to WebSocket","ref":"Mint.WebSocket.UpgradeFailureError.html"},{"type":"function","title":"Mint.WebSocket.UpgradeFailureError.message/1","doc":"","ref":"Mint.WebSocket.UpgradeFailureError.html#message/1"},{"type":"type","title":"Mint.WebSocket.UpgradeFailureError.t/0","doc":"","ref":"Mint.WebSocket.UpgradeFailureError.html#t:t/0"},{"type":"exception","title":"Mint.WebSocketError","doc":"Represents an error in the WebSocket protocol\n\nThe `Mint.WebSocketError` struct is an exception, so it can be raised as\nany other exception.","ref":"Mint.WebSocketError.html"},{"type":"type","title":"Mint.WebSocketError.t/0","doc":"","ref":"Mint.WebSocketError.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a\nChangelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to\n[Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"1.0.4 - 2024-06-14 - Changelog","doc":"","ref":"changelog.html#1-0-4-2024-06-14"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed a compilation warning present with Elixir 1.17+ about \"`4..1`\" not\n  using a range step.","ref":"changelog.html#fixed"},{"type":"extras","title":"1.0.3 - 2023-04-16 - Changelog","doc":"","ref":"changelog.html#1-0-3-2023-04-16"},{"type":"extras","title":"Fixed - Changelog","doc":"- Unexpected continuation frames are now handled.\n    - Previously, unexpected continuation frames received from a server\n      would result in a FunctionClauseError.","ref":"changelog.html#fixed"},{"type":"extras","title":"1.0.2 - 2022-12-11 - Changelog","doc":"","ref":"changelog.html#1-0-2-2022-12-11"},{"type":"extras","title":"Fixed - Changelog","doc":"- Dialyzer errors have been fixed and specs have been improved.","ref":"changelog.html#fixed"},{"type":"extras","title":"1.0.1 - 2022-09-18 - Changelog","doc":"","ref":"changelog.html#1-0-1-2022-09-18"},{"type":"extras","title":"Fixed - Changelog","doc":"- WebSocket frames are now correctly buffered when a partially received\n  frame is split in the payload-length segment.","ref":"changelog.html#fixed"},{"type":"extras","title":"1.0.0 - 2022-04-12 - Changelog","doc":"v1.0.0 is released!\n\nWe've been using `Mint.WebSocket` in production for the better part of a year\nwithout trouble.\n\nv1.0.0 is code-wise the same as v0.3.0: it represents a stability milestone.\n`Mint.WebSocket` will now follow semantic versioning, so any breaking changes\nwill result in a v2.0.0.","ref":"changelog.html#1-0-0-2022-04-12"},{"type":"extras","title":"0.3.0 - 2022-02-27 - Changelog","doc":"","ref":"changelog.html#0-3-0-2022-02-27"},{"type":"extras","title":"Changed - Changelog","doc":"- Failure to upgrade now gives a `Mint.WebSocket.UpgradeFailureError`\n  as the error when a server returns a status code other than 101 for\n  HTTP/1 or a status code outside the range 200..299 range for HTTP/2.","ref":"changelog.html#changed"},{"type":"extras","title":"0.2.0 - 2022-02-17 - Changelog","doc":"This release is a breaking change from the 0.1.0 series. This update removes\nall instances where Mint.WebSocket would access opaque `t:Mint.HTTP.t/0` fields\nor call private functions within `Mint.HTTP1`, so now Mint.WebSocket should be\nmore compatible with future changes to Mint.\n\n#### Upgrade guide\n\nFirst, add the `scheme` argument to calls to `Mint.WebSocket.upgrade/5`.\nFor connections formed with `Mint.HTTP.connect(:http, ..)`, use the `:ws`\nscheme. For `Mint.HTTP.connect(:https, ..)`, use `:wss`.\n\n\n```diff\n- Mint.WebSocket.upgrade(conn, path, headers)\n+ Mint.WebSocket.upgrade(scheme, conn, path, headers)\n```\n\nThen replace calls to `Mint.HTTP.stream/2` and/or `Mint.HTTP.recv/3` and\n`Mint.HTTP.stream_request_body/3` with the new `Mint.WebSocket` wrappers.\nThis is safe to do even when these functions are being used to send and\nreceive data in normal HTTP requests: the functionality only changes when\nthe connection is an established HTTP/1 WebSocket.","ref":"changelog.html#0-2-0-2022-02-17"},{"type":"extras","title":"Added - Changelog","doc":"- Added `Mint.WebSocket.stream/2` which wraps `Mint.HTTP.stream/2`\n- Added `Mint.WebSocket.recv/3` which wraps `Mint.HTTP.recv/3`\n- Added `Mint.WebSocket.stream_request_body/3` which wraps `Mint.HTTP.stream_request_body/3`","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Changed function signature of `Mint.Websocket.upgrade/5` to accept the\n  WebSocket's scheme (`:ws` or `:wss`) as the first argument\n- Added an optional `opts` argument to `Mint.WebSocket.new/5` to control\n  active vs. passive mode on the socket\n- Restricted compatible Mint versions to `~> 1.4`\n    - `Mint.WebSocket` now uses `Mint.HTTP.get_protocol/1` which was\n      introduced in `1.4.0`.","ref":"changelog.html#changed"},{"type":"extras","title":"0.1.4 - 2021-07-06 - Changelog","doc":"","ref":"changelog.html#0-1-4-2021-07-06"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed typespec for `Mint.WebSocket.new/4`","ref":"changelog.html#fixed"},{"type":"extras","title":"0.1.3 - 2021-07-02 - Changelog","doc":"","ref":"changelog.html#0-1-3-2021-07-02"},{"type":"extras","title":"Fixed - Changelog","doc":"- Switch from using `Bitwise.bor/2` to `:erlang.bor/2` for compatibility\n  with Elixir < 1.10","ref":"changelog.html#fixed"},{"type":"extras","title":"0.1.2 - 2021-07-02 - Changelog","doc":"","ref":"changelog.html#0-1-2-2021-07-02"},{"type":"extras","title":"Fixed - Changelog","doc":"- Switch from using `Bitwise.bxor/2` to `:erlang.bxor/2` for compatibility\n  with Elixir < 1.10","ref":"changelog.html#fixed"},{"type":"extras","title":"0.1.1 - 2021-07-01 - Changelog","doc":"","ref":"changelog.html#0-1-1-2021-07-01"},{"type":"extras","title":"Fixed - Changelog","doc":"- Close frame codes and reasons are now nillable instead of defaulted\n  - The WebSocket spec does not require that a code and reason be included\n    for all close frames","ref":"changelog.html#fixed"},{"type":"extras","title":"0.1.0 - 2021-06-30 - Changelog","doc":"","ref":"changelog.html#0-1-0-2021-06-30"},{"type":"extras","title":"Added - Changelog","doc":"- Initial implementation\n    - includes HTTP/1.1 and HTTP/2 support and extensions","ref":"changelog.html#added"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}